@@ -228,9 +228,13 @@ class PredictionController(object):
         """
         Logs a single prediction specifically for Azure App Insight
         """
+        i = input.dict()
+        if 'identifier' in i and isinstance(i['identifier'], Enum):
+            i['identifier'] = i['identifier'].value
+
         self.logger.info('Prediction', extra={
             'custom_dimensions': {
-                'input': json.dumps(input.dict()),
+                'input': json.dumps(i),
                 'prediction': json.dumps(prediction),
             },
         })
